# Beam Section Profile

The Beam Section profile commands are used to create profiles. A profile definition specifies the properties of a beam that are related to its cross-section geometry. When you define a beam section, you must include a reference to a profile in the section definition.

## Create beam section profiles

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileModel.BeamSectionProfileModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileOdb.BeamSectionProfileOdb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.BeamSectionProfile.Profile.Profile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.ArbitraryProfile.ArbitraryProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.BoxProfile.BoxProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.CircularProfile.CircularProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.GeneralizedProfile.GeneralizedProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.HexagonalProfile.HexagonalProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.IProfile.IProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.LProfile.LProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.PipeProfile.PipeProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.RectangularProfile.RectangularProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.TProfile.TProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.BeamSectionProfile.TrapezoidalProfile.TrapezoidalProfile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
